@@ -600,12 +600,11 @@ class WizardDialog(EventsDialog):
         self._on_release = False
 
     def _size_dialog(self, dt):
-        app = App.get_running_app()
-        if app.ui_mode[0] == 'p':
+        if self.app.ui_mode[0] == 'p':
             self.size = Window.size
         else:
             #tablet
-            if app.orientation[0] == 'p':
+            if self.app.orientation[0] == 'p':
                 #portrait
                 self.size = Window.size[0]/1.67, Window.size[1]/1.4
             else:
@@ -622,10 +621,9 @@ class WizardDialog(EventsDialog):
             if self.wizard.can_go_back():
                 self.wizard.go_back()
             else:
-                app = App.get_running_app()
-                if not app.is_exit:
-                    app.is_exit = True
-                    app.show_info(_('Press again to exit'))
+                if not self.app.is_exit:
+                    self.app.is_exit = True
+                    self.app.show_info(_('Press again to exit'))
                 else:
                     self._on_release = False
                     self.dismiss()
@@ -635,9 +633,8 @@ class WizardDialog(EventsDialog):
         Window.unbind(size=self._trigger_size_dialog,
                       rotation=self._trigger_size_dialog,
                       on_keyboard=self.on_keyboard)
-        app = App.get_running_app()
-        if app.wallet is None and not self._on_release:
-            app.stop()
+        if self.app.wallet is None and not self._on_release:
+            self.app.stop()
 
     def get_params(self, button):
         return (None,)
@@ -646,7 +643,7 @@ class WizardDialog(EventsDialog):
         self._on_release = True
         self.close()
         if not button:
-            self.parent.dispatch('on_wizard_complete', None, None)
+            self.wizard.terminate(aborted=True)
             return
         if button is self.ids.back:
             self.wizard.go_back()
@@ -725,7 +722,6 @@ class WizardTOSDialog(WizardDialog):
         self.ids.next.text = 'Accept'
         self.ids.next.disabled = False
         self.message = kwargs['tos']
-        self.message2 = _('Enter your email address:')
 
 class WizardEmailDialog(WizardDialog):
 
@@ -750,8 +746,7 @@ class WizardConfirmDialog(WizardDialog):
 
     def on_parent(self, instance, value):
         if value:
-            app = App.get_running_app()
-            self._back = _back = partial(app.dispatch, 'on_back')
+            self._back = _back = partial(self.app.dispatch, 'on_back')
 
     def get_params(self, button):
         return (True,)
@@ -778,8 +773,7 @@ class WizardChoiceDialog(WizardDialog):
 
     def on_parent(self, instance, value):
         if value:
-            app = App.get_running_app()
-            self._back = _back = partial(app.dispatch, 'on_back')
+            self._back = _back = partial(self.app.dispatch, 'on_back')
 
     def get_params(self, button):
         return (button.action,)
@@ -845,7 +839,6 @@ class ShowSeedDialog(WizardDialog):
 
     def on_parent(self, instance, value):
         if value:
-            app = App.get_running_app()
             self._back = _back = partial(self.ids.back.dispatch, 'on_release')
 
     def options_dialog(self):
@@ -963,7 +956,6 @@ class RestoreSeedDialog(WizardDialog):
             #tis._keyboard.bind(on_key_down=self.on_key_down)
             self._back = _back = partial(self.ids.back.dispatch,
                                          'on_release')
-            app = App.get_running_app()
 
     def on_key_down(self, keyboard, keycode, key, modifiers):
         if keycode[0] in (13, 271):
@@ -992,6 +984,7 @@ class ConfirmSeedDialog(RestoreSeedDialog):
     def __init__(self, *args, **kwargs):
         RestoreSeedDialog.__init__(self, *args, **kwargs)
         self.ids.seed_dialog_header.ids.options_button.disabled = True
+        self.ids.text_input_seed.text = kwargs['seed']
 
     def get_params(self, b):
         return (self.get_text(),)
@@ -1060,51 +1053,23 @@ class AddXpubDialog(WizardDialog):
 
 
 class InstallWizard(BaseWizard, Widget):
-    '''
-    events::
-        `on_wizard_complete` Fired when the wizard is done creating/ restoring
-        wallet/s.
-    '''
 
-    __events__ = ('on_wizard_complete', )
-
-    def on_wizard_complete(self, storage, db):
-        """overriden by main_window"""
-        pass
-
-    def waiting_dialog(self, task, msg, on_finished=None):
-        '''Perform a blocking task in the background by running the passed
-        method in a thread.
-        '''
-        def target():
-            # run your threaded function
-            try:
-                task()
-            except Exception as err:
-                self.logger.exception('')
-                self.show_error(str(err))
-            # on  completion hide message
-            Clock.schedule_once(lambda dt: app.info_bubble.hide(now=True), -1)
-            if on_finished:
-                def protected_on_finished():
-                    try:
-                        on_finished()
-                    except Exception as e:
-                        self.logger.exception('')
-                        self.show_error(str(e))
-                Clock.schedule_once(lambda dt: protected_on_finished(), -1)
-
-        app = App.get_running_app()
-        app.show_info_bubble(
-            text=msg, icon='atlas://electrum/gui/kivy/theming/light/important',
-            pos=Window.center, width='200sp', arrow_pos=None, modal=True)
-        t = threading.Thread(target = target)
-        t.start()
+    def __init__(self, *args, **kwargs):
+        BaseWizard.__init__(self, *args, **kwargs)
+        self.app = App.get_running_app()
 
     def terminate(self, *, storage=None, db=None, aborted=False):
-        if storage is None and not aborted:
+        # storage must be None because manual upgrades are disabled on Kivy
+        assert storage is None
+        if not aborted:
+            password = self.pw_args.password
             storage, db = self.create_storage(self.path)
-        self.dispatch('on_wizard_complete', storage, db)
+            self.app.on_wizard_success(storage, db, password)
+        else:
+            try: os.unlink(self.path)
+            except FileNotFoundError: pass
+            self.reset_stack()
+            self.confirm_dialog(message=_('Wallet creation failed'), run_next=self.app.on_wizard_aborted)
 
     def choice_dialog(self, **kwargs):
         choices = kwargs['choices']
@@ -1156,8 +1121,7 @@ class InstallWizard(BaseWizard, Widget):
     def show_message(self, msg): self.show_error(msg)
 
     def show_error(self, msg):
-        app = App.get_running_app()  # type: ElectrumWindow
-        Clock.schedule_once(lambda dt: app.show_error(msg))
+        Clock.schedule_once(lambda dt: self.app.show_error(msg))
 
     def request_password(self, run_next, force_disable_encrypt_cb=False):
         if force_disable_encrypt_cb:
@@ -1169,10 +1133,9 @@ class InstallWizard(BaseWizard, Widget):
             run_next(pw, True)
         def on_failure():
             self.show_error(_('Password mismatch'))
-            self.run('request_password', run_next)
-        app = App.get_running_app()
+            self.request_password(run_next)
         popup = PasswordDialog(
-            app,
+            self.app,
             check_password=lambda x:True,
             on_success=on_success,
             on_failure=on_failure,
